@@ -3,6 +3,7 @@ import sys
 import re
 import time
 import datetime
+from bukget import api
 from zipfile import ZipFile
 from commands import getoutput as run
 from ConfigParser import ConfigParser
@@ -30,6 +31,7 @@ class Server(object):
     env = './'
     binary = 'server.jar'
     server_type = 'vanilla'
+    bin = 'vanilla'
     server_branch = 'stable'
     server_build = '1.0'
     worlds = []
@@ -460,6 +462,7 @@ class Server(object):
         if not os.path.exists(path):
             os.makedirs(path)
 
+
     def _sync(self, from_path, to_path):
         '''Internal Function
         Convenience function for rsyncing.  Will use a lockfile with the
@@ -481,4 +484,11 @@ class Server(object):
         run(rsync_cmd)
         
         # Remove the lockfile
-        os.remove(lockfile)
\ No newline at end of file
+        os.remove(lockfile)
+
+
+    def plugin_install(self, plugin, version):
+        '''
+        Installs a plugin using BukGet API.
+        '''
+        plug = api.plugin_details(self., plugin, version)
